==> v2.1.14.zip: component-builder/README.md <==
# Component Builder (2.1.14)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Component Builder image] (https://raw.githubusercontent.com/vdm-io/Joomla-Component-Builder/master/admin/assets/images/component-300.png "The Component Builder")

The Component Builder for Joomla that is highly advanced, truly able to build extremely complex components in a fraction of the time.

> **You can purchase demo content inside Component Builder:**

+ **Development Version** ([get this demo set](https://www.vdm.io/joomla-component-builder))

    *Help View Integration*

    *Demo Component* see the build on [github] (https://github.com/namibia/demo-joomla-3-component)

+ **Dev + Howtos Version** ([get this demo set](https://www.vdm.io/joomla-component-builder))

    *All the above*

    *Sermon Distributor* see the build on [github] (https://github.com/SermonDistributor/Joomla-3-Component)

    *Training & Help Videos* tutorials in the component included.

# gitHub Support

Would you require more help please open and issue here on [gitHub today](https://github.com/vdm-io/Joomla-Component-Builder/issues)!

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/joomla-component-builder)
+ *Author*: [Llewellyn van der Merwe] (mailto:info@vdm.io)
+ *Name*: [Component Builder] (https://www.vdm.io/joomla-component-builder)
+ *First Build*: 30th April, 2015
+ *Last Build*: 27th June, 2016
+ *Version*: 2.1.14
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **83201**
+ *File count*: **507**
+ *Folder count*: **98**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

==> v2.1.16.zip: component-builder/README.md <==
# Component Builder (2.1.16)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Component Builder image] (https://raw.githubusercontent.com/vdm-io/Joomla-Component-Builder/master/admin/assets/images/component-300.jpg "The Component Builder")

The Component Builder for Joomla that is highly advanced, truly able to build extremely complex components in a fraction of the time.

> **You can purchase demo content inside Component Builder:**

+ **Development Version** ([get this demo set](https://www.vdm.io/joomla-component-builder))

    *Help View Integration*

    *Demo Component* see the build on [github] (https://github.com/namibia/demo-joomla-3-component)

+ **Dev + Howtos Version** ([get this demo set](https://www.vdm.io/joomla-component-builder))

    *All the above*

    *Sermon Distributor* see the build on [github] (https://github.com/SermonDistributor/Joomla-3-Component)

    *Training & Help Videos* tutorials in the component included.

# gitHub Support

Would you require more help please open and issue here on [gitHub today](https://github.com/vdm-io/Joomla-Component-Builder/issues)!

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/joomla-component-builder)
+ *Author*: [Llewellyn van der Merwe] (mailto:info@vdm.io)
+ *Name*: [Component Builder] (https://www.vdm.io/joomla-component-builder)
+ *First Build*: 30th April, 2015
+ *Last Build*: 12th July, 2016
+ *Version*: 2.1.16
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **83187**
+ *File count*: **509**
+ *Folder count*: **98**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)
